// An XML file is validated.

import java.io.*;
import javax.xml.parsers.*;
import javax.xml.transform.*;
import javax.xml.transform.dom.*;
import javax.xml.transform.stream.*;
import org.w3c.dom.*;
import org.xml.sax.*;

class XmlValidate {

    // Validation is by schema.
    static final String JAXP_SCHEMA_LANGUAGE =
            "http://java.sun.com/xml/jaxp/properties/schemaLanguage";
    static final String W3C_XML_SCHEMA =
            "http://www.w3.org/2001/XMLSchema";

    // Transform source according to XSLT.
    private static void validate(String in) {

        // get parser
        DocumentBuilder builder;
        try {
            DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
            factory.setValidating(true);
            factory.setNamespaceAware(true);
            factory.setAttribute(JAXP_SCHEMA_LANGUAGE, W3C_XML_SCHEMA);
            builder = factory.newDocumentBuilder();
            builder.setErrorHandler(new XmlErrorHandler());
        } catch (ParserConfigurationException e) {
            System.err.println(e.getMessage());
            return;
        }
        // parse
        Document document = null;
        try {
            document = builder.parse(in);
        } catch (IOException e) {
            System.err.println(e.getMessage());
            return;
        } catch (SAXException e) {
            System.err.println(e.getMessage());
            return;
        }

    }

    // All arguments are XML files to be validated.
    public static void main(String[] args) {
	for (int i = 0; i < args.length; i++) 
            validate(args[i]);
    }

}
