// An XML file is transformed.

import java.io.*;
import javax.xml.parsers.*;
import javax.xml.transform.*;
import javax.xml.transform.dom.*;
import javax.xml.transform.stream.*;
import org.w3c.dom.*;
import org.xml.sax.*;

class XslTransform {

	// Validation is by schema.
	static final String JAXP_SCHEMA_LANGUAGE =
			"http://java.sun.com/xml/jaxp/properties/schemaLanguage";
	static final String W3C_XML_SCHEMA =
			"http://www.w3.org/2001/XMLSchema";

	// Transform source according to XSLT.
	private static void transform(String in, String xslt, PrintStream out) {

		// get parser
		DocumentBuilder builder;
		try {
			DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
			factory.setValidating(false);
			factory.setNamespaceAware(true);
			factory.setAttribute(JAXP_SCHEMA_LANGUAGE, W3C_XML_SCHEMA);
			builder = factory.newDocumentBuilder();
			builder.setErrorHandler(new XmlErrorHandler());
		} catch (ParserConfigurationException e) {
			System.err.println(e.getMessage());
			return;
		}
		// parse
		Document document = null;
		try {
			document = builder.parse(in); 
		} catch (IOException e) {
			System.err.println(e.getMessage());
			return;
		} catch (SAXException e) {
			System.err.println(e.getMessage());
			return;
		}
		Source source = new DOMSource(document); 

		// get transformation
		Source xsltSource = new StreamSource(new File(xslt)); 
		// get transformer
		Transformer transformer = null;
		try {
			TransformerFactory factory = TransformerFactory.newInstance();
			Templates transformation = factory.newTemplates(xsltSource);
			transformer = transformation.newTransformer();
		} catch (TransformerConfigurationException e) {
			System.err.println(e.getMessage());
			return;
		}

		// get target
		Result result = new StreamResult(out); 

		// transform
		try {
			transformer.transform(source, result);
		} catch (TransformerException e) {
			System.err.println(e.getMessage());
			return;
		}

	}

	// The source, the XSLT input, and output file are the arguments.
	// If the third argument is missing, standard output is taken.
	public static void main(String[] args) {
		if (args.length >= 2) { 
			PrintStream out = System.out;
			if (args.length > 2) 
				try {
					out = new PrintStream(
							new FileOutputStream(args[2]));
				} catch (FileNotFoundException e) {
					System.err.println(e.getMessage());
					return;
				}
			transform(args[0], args[1], out);
		}
	}

}
