#!/bin/bash

# Input consists of triples of lines. Of such a triple,
# the first is a filename of a file that is to be produced, 
# the second is the data from which the file is to be produced,
# and the third a shell command that produces that file,
# assuming that the data has been copied to $tmp.
# If the file has not yet been produced with that command 
# and the data, or if the file does not exist,
# then the file is produced and the data and the command are
# stored in filename plus ".txt". Otherwise nothing happens.

# Temporary file for data.
tmp="makelazytmp"
# Temporary file holding data plus shell command.
ctmp="makelazyctmp"

# Read from standard input or from file.
FILE=""
if [[ "$1" == "" ]]; 
then
    FILE="/dev/stdin"
else
    FILE="$1"
    if [[ ! -f $FILE ]]; 
    then
	echo "$FILE: does not exists"
	exit 1
    elif [[ ! -r $FILE ]]; 
    then
	echo "$FILE: cannot be read"
	exit 1
    fi
fi

# Read from FILE.
BAKIFS=$IFS
IFS=$(echo -en "\n\b")
exec 3<&0
exec 0<"$FILE"

# Read triples (filename, data, command).
while read filename
do
    if read data;
    then 
	if read command;
	then

	    echo "$data" > $tmp
	    if [[ ! -e "$filename.txt" ]]; 
	    then
		echo "makelazy.sh is making $filename"
		eval "$command"
	    else
		echo $data > "$ctmp"
		echo $command >> "$ctmp"
		diff "$filename.txt" "$ctmp" > /dev/null
		if [[ $? = 1 || ! -e $filename ]];
		then
		    echo "makelazy.sh is making $filename"
		    eval "$command"
		fi
	    fi
	    echo $data > "$filename.txt"
	    echo $command >> "$filename.txt"

	else
	    echo "missing command, number of lines should be multiple of 3"
	    exit 1
	fi
    else
	echo "missing data, number of lines should be multiple of 3"
	exit 1
    fi
done

# Restore reading.
exec 0<&3
IFS=$BAKIFS

# Cleanup.
rm $tmp 2>/dev/null
rm $ctmp 2>/dev/null

exit 0
