<?xml version="1.0" encoding="UTF-8"?>

<xsl:stylesheet version="1.0"
        xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

    <xsl:output method="xml" />

    <xsl:variable name="use" select="document('signuse.xml')" />

    <xsl:template match="signlist">
        <signinfo>
	    <xsl:call-template name="newline" />
	    <xsl:apply-templates select="sign" />
        </signinfo>
    </xsl:template>

    <xsl:template match="sign">
        <xsl:variable name="signid" select="@id" />
        <xsl:variable name="readings"
            select="$use/signlist/sign[@id=$signid]/*" />
	<xsl:call-template name="signreadings">
	    <xsl:with-param name="readings" select="$readings" />
	    <xsl:with-param name="signid" select="$signid" />
	    <xsl:with-param name="seen" select="' '" />
	</xsl:call-template>
    </xsl:template>

    <xsl:template name="signreadings">
	<xsl:param name="readings" />
	<xsl:param name="signid" />
	<xsl:param name="seen" />
	<xsl:for-each select="$readings[name()!='p' and not(@type='group')]">
	    <xsl:choose>
		<xsl:when test="name()='useas' and not(@number)">
		    <xsl:variable name="name" select="@name" />
		    <xsl:variable name="useid" select="@useref" />
		    <xsl:choose>
			<xsl:when test="contains($seen,concat(concat(' ', $name),' '))">
			    <!-- avoid looping for recursion -->
			</xsl:when>
			<xsl:when test="$useid">
			    <xsl:variable name="useas-readings"
				select="$use/signlist/sign[@id=$name]/*[@useid=$useid]" />
			    <xsl:call-template name="signreadings">
				<xsl:with-param name="readings" select="$useas-readings" />
				<xsl:with-param name="signid" select="$signid" />
				<xsl:with-param name="seen" 
						select="concat(concat($seen,' '),$name)" />
			    </xsl:call-template>
			</xsl:when>
			<xsl:when test="group">
			    <xsl:variable name="useas-readings"
				select="$use/signlist/sign[@id=$name]/*" />
			    <xsl:for-each select="group">
				<xsl:variable name="group" select="." />
				<xsl:call-template name="signreadings">
				    <xsl:with-param name="readings" select="$useas-readings" />
				    <xsl:with-param name="signid" select="$group" />
				    <xsl:with-param name="seen" 
						    select="concat(concat($seen,' '),$name)" />
				</xsl:call-template>
			    </xsl:for-each>
			</xsl:when>
			<xsl:otherwise>
			    <xsl:variable name="useas-readings"
				select="$use/signlist/sign[@id=$name]/*" />
			    <xsl:call-template name="signreadings">
				<xsl:with-param name="readings" select="$useas-readings" />
				<xsl:with-param name="signid" select="$signid" />
				<xsl:with-param name="seen" 
						select="concat(concat($seen,' '),$name)" />
			    </xsl:call-template>
			</xsl:otherwise>
		    </xsl:choose>
		    <xsl:call-template name="useas-spec">
			<xsl:with-param name="id" select="$signid" />
			<xsl:with-param name="alt" select="$name" />
			<xsl:with-param name="num" select="'1'" />
			<xsl:with-param name="reading" select="." />
		    </xsl:call-template>
		</xsl:when>
		<xsl:when test="name()='useas' and @number">
		    <xsl:variable name="name" select="@name" />
		    <xsl:variable name="num" select="@number" />
		    <xsl:call-template name="useas-spec">
			<xsl:with-param name="id" select="$signid" />
			<xsl:with-param name="alt" select="$name" />
			<xsl:with-param name="num" select="$num" />
			<xsl:with-param name="reading" select="." />
		    </xsl:call-template>
		</xsl:when>
		<xsl:when test="name()='logdet'">
		    <xsl:call-template name="spec">
			<xsl:with-param name="class" select="'log'" />
			<xsl:with-param name="id" select="$signid" />
			<xsl:with-param name="reading" select="." />
		    </xsl:call-template>
		    <xsl:call-template name="spec">
			<xsl:with-param name="class" select="'det'" />
			<xsl:with-param name="id" select="$signid" />
			<xsl:with-param name="reading" select="." />
		    </xsl:call-template>
		</xsl:when>
		<xsl:when test="name()='phonphondet'">
		    <xsl:call-template name="spec">
			<xsl:with-param name="class" select="'phon'" />
			<xsl:with-param name="id" select="$signid" />
			<xsl:with-param name="reading" select="." />
		    </xsl:call-template>
		    <xsl:call-template name="spec">
			<xsl:with-param name="class" select="'phondet'" />
			<xsl:with-param name="id" select="$signid" />
			<xsl:with-param name="reading" select="." />
		    </xsl:call-template>
		</xsl:when>
		<xsl:otherwise>
		    <xsl:call-template name="spec">
			<xsl:with-param name="class" select="name()" />
			<xsl:with-param name="id" select="$signid" />
			<xsl:with-param name="reading" select="." />
		    </xsl:call-template>
		</xsl:otherwise>
	    </xsl:choose>
	</xsl:for-each>
    </xsl:template>

    <xsl:template name="spec">
	<xsl:param name="class" />
	<xsl:param name="id" />
	<xsl:param name="reading" />
	<xsl:choose>
	    <xsl:when test="$reading/group">
		<xsl:for-each select="$reading/group">
		    <xsl:variable name="hi" select="." />
		    <xsl:for-each select="$reading/al">
			<xsl:element name="{$class}">
			    <xsl:call-template name="hieroglyphic">
			       <xsl:with-param name="node" select="$hi" />
			    </xsl:call-template>
			    <xsl:call-template name="transliteration">
			       <xsl:with-param name="node" select="." />
			    </xsl:call-template>
			</xsl:element>
			<xsl:call-template name="newline" />
		    </xsl:for-each>
		    <xsl:if test="not($reading/al)">
			<xsl:choose>
			    <xsl:when test="$reading/describe and $class='det'">
				<xsl:element name="det-descr">
				    <xsl:if test="$reading/@dual='true'">
					<xsl:attribute name="dual">true</xsl:attribute>
				    </xsl:if>
				    <xsl:if test="$reading/@plural='true'">
					<xsl:attribute name="plural">true</xsl:attribute>
				    </xsl:if>
				    <xsl:call-template name="hieroglyphic">
					<xsl:with-param name="node" select="$hi" />
				    </xsl:call-template>
				    <xsl:call-template name="description">
					<xsl:with-param name="node" select="$reading/describe" />
				    </xsl:call-template>
				</xsl:element>
			    </xsl:when>
			    <xsl:when test="$reading/describe and $class='typ'">
				<xsl:element name="typ">
				    <xsl:call-template name="hieroglyphic">
					<xsl:with-param name="node" select="$hi" />
				    </xsl:call-template>
				    <xsl:call-template name="description">
					<xsl:with-param name="node" select="$reading/describe" />
				    </xsl:call-template>
				</xsl:element>
			    </xsl:when>
			    <xsl:otherwise>
				<xsl:element name="{$class}">
				    <xsl:call-template name="hieroglyphic">
					<xsl:with-param name="node" select="$hi" />
				    </xsl:call-template>
				</xsl:element>
			    </xsl:otherwise>
			</xsl:choose>
			<xsl:call-template name="newline" />
		    </xsl:if>
		</xsl:for-each>
	    </xsl:when>
	    <xsl:otherwise>
		<xsl:variable name="hi" select="$id" />
		<xsl:for-each select="$reading/al">
		    <xsl:element name="{$class}">
			<xsl:call-template name="hieroglyphic">
			   <xsl:with-param name="node" select="$id" />
			</xsl:call-template>
			<xsl:call-template name="transliteration">
			   <xsl:with-param name="node" select="." />
			</xsl:call-template>
		    </xsl:element>
		    <xsl:call-template name="newline" />
		</xsl:for-each>
		<xsl:if test="not($reading/al)">
		    <xsl:choose>
			<xsl:when test="$reading/describe and $class='det'">
			    <xsl:element name="det-descr">
				<xsl:call-template name="hieroglyphic">
				    <xsl:with-param name="node" select="$hi" />
				</xsl:call-template>
				<xsl:call-template name="description">
				    <xsl:with-param name="node" select="$reading/describe" />
				</xsl:call-template>
			    </xsl:element>
			</xsl:when>
			<xsl:when test="$reading/describe and $class='typ'">
			    <xsl:element name="typ">
				<xsl:call-template name="hieroglyphic">
				    <xsl:with-param name="node" select="$hi" />
				</xsl:call-template>
				<xsl:call-template name="description">
				    <xsl:with-param name="node" select="$reading/describe" />
				</xsl:call-template>
			    </xsl:element>
			</xsl:when>
			<xsl:otherwise>
			    <xsl:element name="{$class}">
				<xsl:call-template name="hieroglyphic">
				    <xsl:with-param name="node" select="$hi" />
				</xsl:call-template>
			    </xsl:element>
			</xsl:otherwise>
		    </xsl:choose>
		    <xsl:call-template name="newline" />
		</xsl:if>
		<xsl:for-each select="$reading[@numeral]/tr">
		    <xsl:element name="num">
			<xsl:call-template name="hieroglyphic">
			   <xsl:with-param name="node" select="$hi" />
			</xsl:call-template>
			<xsl:call-template name="transliteration">
			   <xsl:with-param name="node" select="../@numeral" />
			</xsl:call-template>
		    </xsl:element>
		    <xsl:call-template name="newline" />
		</xsl:for-each>
	    </xsl:otherwise>
	</xsl:choose>
    </xsl:template>

    <xsl:template name="useas-spec">
	<xsl:param name="id" />
	<xsl:param name="alt" />
	<xsl:param name="num" />
	<xsl:param name="reading" />
	<xsl:choose>
	    <xsl:when test="$reading/group">
		<xsl:for-each select="$reading/group">
		    <xsl:variable name="hi" select="." />
		    <xsl:element name="useas">
			<xsl:attribute name="alt">
			    <xsl:value-of select="$alt" />
			</xsl:attribute>
			<xsl:attribute name="num">
			    <xsl:value-of select="$num" />
			</xsl:attribute>
			<xsl:call-template name="hieroglyphic">
			   <xsl:with-param name="node" select="$hi" />
			</xsl:call-template>
		    </xsl:element>
		    <xsl:call-template name="newline" />
		</xsl:for-each>
	    </xsl:when>
	    <xsl:otherwise>
		<xsl:variable name="hi" select="$id" />
		<xsl:element name="useas">
		    <xsl:attribute name="alt">
			<xsl:value-of select="$alt" />
		    </xsl:attribute>
		    <xsl:attribute name="num">
			<xsl:value-of select="$num" />
		    </xsl:attribute>
		    <xsl:call-template name="hieroglyphic">
		       <xsl:with-param name="node" select="$id" />
		    </xsl:call-template>
		</xsl:element>
		<xsl:call-template name="newline" />
	    </xsl:otherwise>
	</xsl:choose>
    </xsl:template>

    <xsl:template name="hieroglyphic">
        <xsl:param name="node" />
        <hi><xsl:value-of select="$node" /></hi>
    </xsl:template>

    <xsl:template name="description">
        <xsl:param name="node" />
        <descr><xsl:value-of select="$node" /></descr>
    </xsl:template>

    <xsl:template name="transliteration">
        <xsl:param name="node" />
        <al>
	    <xsl:if test="@root">
		<xsl:attribute name="root">
		    <xsl:value-of select="@root" />
		</xsl:attribute>
	    </xsl:if>
	    <xsl:value-of select="$node" />
	</al>
    </xsl:template>

<!-- Auxiliary -->

    <xsl:template name="newline">
        <xsl:text>
</xsl:text>
    </xsl:template>

</xsl:stylesheet>
