<?xml version="1.0" encoding="UTF-8"?>

<!DOCTYPE xsl:stylesheet [
<!ENTITY nbsp "&#160;">
<!ENTITY times "&#215;">
]>

<xsl:stylesheet version="1.0"
	   xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

	<xsl:output method="html" />

	<xsl:import href="transformbase.xsl" />

	<xsl:template name="style">
		<link rel="stylesheet" type="text/css" href="res.css" />
		<script type="text/javascript" src="res_aux.js"></script>
		<script type="text/javascript" src="res_points.js"></script>
		<script type="text/javascript" src="res_lite.js"></script>
		<script type="text/javascript" src="res_struct.js"></script>
		<script type="text/javascript" src="res_syntax.js"></script>
		<script type="text/javascript" src="res_format.js"></script>
		<script type="text/javascript" src="res_render.js"></script>
		<script type="text/javascript" src="res_web.js"></script>
		<link rel="stylesheet" type="text/css" href="unicode.css" />
	</xsl:template>
		
    <xsl:template name="font-hack">
		<!-- hack to force timely loading of fonts -->
		<div id="outsidescreen">
			<span class="outsidescreen_elem hi">&#57344;</span>
			<span class="outsidescreen_elem hiaux">&#35;</span>
			<span class="outsidescreen_elem hinotes">&#35;</span>
		</div>
	</xsl:template>

	<xsl:template name="cite-list">
		<xsl:param name="list" />
		<xsl:for-each select="$list/cite">
			<xsl:apply-templates select="."/>
			<xsl:if test="position()&lt;last()">
				<xsl:text>, </xsl:text>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>

	<xsl:template match="cite">
		<xsl:variable name="refid" select="@ref" />
		<xsl:variable name="p" select="@page" />
		<xsl:variable name="no" select="@number" />
		<xsl:variable name="vol" select="@volume" />
		<xsl:variable name="com" select="@comment" />
		<xsl:for-each select="$bibl/bibliography/item[@id=$refid]">
			<a>
				<xsl:attribute name="href">#<xsl:value-of select='$refid' />
				</xsl:attribute>
				<xsl:value-of select="@author" />
			</a>
			<xsl:if test="not(normalize-space($vol)='')">
				<xsl:text>:</xsl:text>
				<xsl:value-of select="$vol" />
			</xsl:if>
			<xsl:if test="not(normalize-space($p)='')">
				<xsl:text>:</xsl:text>
				<xsl:value-of select="$p" />
			</xsl:if>
			<xsl:if test="not(normalize-space($no)='')">
				<xsl:text>:</xsl:text>
				<xsl:value-of select="$no" />
			</xsl:if>
			<xsl:if test="not(normalize-space($com)='')">
				<xsl:text> (</xsl:text>
				<xsl:value-of select="$com" />
				<xsl:text>)</xsl:text>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>

	<xsl:template match="publications">
		<ul>
			<xsl:apply-templates/>
		</ul>
	</xsl:template>

	<xsl:template match="publication">
		<xsl:variable name="refid" select="@ref" />
		<xsl:for-each select="$bibl/bibliography/item[@id=$refid]">
			<li>
			<a>
				<xsl:attribute name="name"><xsl:value-of select='$refid' />
				</xsl:attribute>
				<b><xsl:value-of select="@author" /></b>
			</a>,
			<xsl:apply-templates />
			</li>
		</xsl:for-each>
	</xsl:template>

	<xsl:template match="title">
		<i><xsl:apply-templates /></i>
	</xsl:template>

	<xsl:template name="citemarker">
		<sup class="super">
			<xsl:value-of select="
				count(
				parent::*/preceding-sibling::*/descendant::*/@cite[. != '']) 
				+ count(
				parent::*/parent::*/preceding-sibling::*/descendant::*/@cite[. != '']) 
				+ 1" />
		</sup>
	</xsl:template>

	<xsl:template name="listcites">
		<xsl:param name="readings" />
		<xsl:variable name="cites" select="$readings/descendant::*/@cite[. != '']" />
		<xsl:if test="count($cites) > 0">
			<p class="footnote">
			<xsl:for-each select="$cites">
				<sup class="super">
					<xsl:value-of select="position()" />
				</sup>
				<xsl:text>&nbsp;</xsl:text>
				<xsl:value-of select="." />
				<xsl:text>. </xsl:text>
			</xsl:for-each>
			</p>
		</xsl:if>
	</xsl:template>

	<xsl:template name="length">
		<xsl:param name="node" />
		<xsl:param name="dimension" />
		<xsl:if test="not($node='')">
			<xsl:choose>
				<xsl:when test="$node/@type='eq' or not($node/@type)">
					<xsl:value-of select="$dimension" />=<xsl:value-of select="$node" />
				</xsl:when>
				<xsl:when test="$node/@type='lt'">
					<xsl:value-of select="$dimension" />&lt;<xsl:value-of select="$node" />
				</xsl:when>
				<xsl:when test="$node/@type='approx'">
					<xsl:value-of select="$dimension" />~<xsl:value-of select="$node" />
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$node" />
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
	</xsl:template>

<!-- Specific to HTML -->

	<xsl:template name="highlighted-class-name">
		<xsl:param name="class" />
		<span class="class">
			<xsl:call-template name="class-name">
				<xsl:with-param name="class" select="$class" />
			</xsl:call-template>
		</span>
	</xsl:template>

	<xsl:template name="highlighted-ex">
		<span class="ex">Ex. </span>
	</xsl:template>

	<xsl:template name="highlighted-exx">
		<span class="ex">Exx. </span>
	</xsl:template>

	<xsl:template name="example-environment">
		<span class="nobreak">
			<xsl:call-template name="example" />
		</span>
	</xsl:template>

	<xsl:template name="hieroglyphic">
		<xsl:param name="node" />
		<canvas class="res"><xsl:value-of select="$node" /></canvas>
	</xsl:template>

	<xsl:template name="sign">
		<xsl:param name="signid" />
		<span class="sign"><xsl:value-of select="$signid" /></span>
	</xsl:template>

	<xsl:template name="sign-and-id">
		<xsl:param name="signid" />
		<xsl:call-template name="sign">
			<xsl:with-param name="signid" select="$signid" />
		</xsl:call-template>
		<xsl:text>&nbsp;&nbsp;</xsl:text>
		<xsl:value-of select="$signid" />
	</xsl:template>

	<xsl:template name="sign-and-formal">
		<xsl:param name="signid" />
		<xsl:call-template name="sign">
			<xsl:with-param name="signid" select="$signid" />
		</xsl:call-template>
		<xsl:text>&nbsp;&nbsp;</xsl:text>
		<xsl:value-of select="$formal/signlist/sign[@id=$signid]/@formal" />
	</xsl:template>

	<xsl:template name="transliteration">
		<xsl:param name="certain" />
		<xsl:param name="node" />
		<xsl:if test="$certain='false'">
			<xsl:text>* </xsl:text>
		</xsl:if>
		<span class="trans"><xsl:value-of select="$node" /></span>
	</xsl:template>

	<xsl:template name="translation">
		<xsl:param name="certain" />
		<xsl:param name="node" />
		<xsl:text>"</xsl:text>
		<xsl:if test="$certain='false'">
			<xsl:text>* </xsl:text>
		</xsl:if>
		<xsl:value-of select="$node" />
		<xsl:text>"</xsl:text>
	</xsl:template>

	<xsl:template name="optional-citemarker">
		<xsl:call-template name="citemarker" />
	</xsl:template>

	<xsl:template name="hyperlink">
		<xsl:param name="name" />
		<xsl:text>&nbsp;</xsl:text>
		<a>
			<xsl:attribute name="href">#<xsl:value-of select='$name' />
			</xsl:attribute>
			<xsl:value-of select="$name" />
		</a>
	</xsl:template>

	<xsl:template name="times-symbol">
		<xsl:text>&times;&nbsp;</xsl:text>
	</xsl:template>

</xsl:stylesheet>
