<?xml version="1.0" encoding="UTF-8"?>

<xsl:stylesheet version="1.0"
		xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

	<xsl:output method="xml" />

	<xsl:import href="transformbase.xsl" />

	<xsl:template match="signlist">
		<xsl:call-template name="newline" />
		<signinfo>
			<xsl:apply-templates select="sign" />
			<xsl:call-template name="newline" />
			<xsl:call-template name="newline" />
		</signinfo>
	</xsl:template>

	<xsl:template match="sign">
		<xsl:variable name="signid" select="@id" />
		<xsl:variable name="descr"
			select="$description/signlist/sign[@id=$signid]" />
		<xsl:variable name="readings"
			select="$use/signlist/sign[@id=$signid]" />
		<xsl:variable name="others"
			select="$relations/signlist/sign[@id=$signid]" />

		<xsl:call-template name="newline" />
		<xsl:call-template name="newline" />
		<sign>
			<xsl:attribute name="name">
				<xsl:value-of select="$signid" />
			</xsl:attribute>
			<descr>
				<xsl:choose>
					<xsl:when test="$descr/descr/node()">
						<xsl:apply-templates select="$descr/descr/node()" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>...</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</descr>
			
			<xsl:call-template name="newline" />
			<info>
				<xsl:for-each select="$readings/*[name()!='p']">
					<xsl:call-template name="newline" />
					<p> <xsl:apply-templates select="." /> </p>
				</xsl:for-each>

				<xsl:for-each select="$readings/p">
					<xsl:call-template name="newline" />
					<p><xsl:apply-templates /></p>
				</xsl:for-each>

				<xsl:if test="$relations/signlist/sign[distinct/@name=$signid] or $others/distinct">
					<xsl:call-template name="newline" />
					<p>
						<xsl:text>Do not confuse with: </xsl:text>
						<xsl:for-each
							select="$relations/signlist/sign[distinct/@name=$signid]">
							<xsl:call-template name="signreference">
								<xsl:with-param name="name" select="@id" />
							</xsl:call-template>
							<xsl:if test="position()&lt;last() or $others/distinct">
								<xsl:text>, </xsl:text>
							</xsl:if>
						</xsl:for-each>
						<xsl:for-each select="$others/distinct">
							<xsl:call-template name="signreference">
								<xsl:with-param name="name" select="@name" />
							</xsl:call-template>
							<xsl:if test="position()&lt;last()">
								<xsl:text>, </xsl:text>
							</xsl:if>
						</xsl:for-each>
						<xsl:text>. </xsl:text>
					</p>
				</xsl:if>

				<xsl:if test="$mnemonics/signlist/sign[@id=$signid]">
					<xsl:call-template name="newline" />
					<p>
						<xsl:text>Mnemonics: </xsl:text>
						<xsl:for-each select="$mnemonics/signlist/sign[@id=$signid]">
							<xsl:value-of select="@code" />
							<xsl:if test="position()&lt;last()">
								<xsl:text>, </xsl:text>
							</xsl:if>
						</xsl:for-each>
						<xsl:text>.</xsl:text>
					</p>
				</xsl:if>
			</info>
		</sign>
	</xsl:template>

<!-- Specific to PhilologEg -->

	<xsl:template name="highlighted-class-name">
		<xsl:param name="class" />
		<xsl:call-template name="class-name">
			<xsl:with-param name="class" select="name()" />
		</xsl:call-template>
	</xsl:template>

	<xsl:template name="highlighted-ex">
		<xsl:text>Ex. </xsl:text>
	</xsl:template>

	<xsl:template name="highlighted-exx">
		<xsl:text>Exx. </xsl:text>
	</xsl:template>

	<xsl:template name="example-environment">
		<xsl:call-template name="example" />
	</xsl:template>

   <xsl:template name="hieroglyphic">
		<xsl:param name="node" />
		<hi><xsl:value-of select="$node" /></hi>
		<xsl:text> </xsl:text>
	</xsl:template>

   <xsl:template name="sign">
        <xsl:param name="signid" />
        <hi><xsl:value-of select="$signid" /></hi>
        <xsl:text> </xsl:text>
    </xsl:template>

	<xsl:template name="transliteration">
		<xsl:param name="certain" />
		<xsl:param name="node" />
		<xsl:if test="$certain='false'">
			<xsl:text>* </xsl:text>
		</xsl:if>
		<al><xsl:value-of select="$node" /></al>
	</xsl:template>

	<xsl:template name="translation">
		<xsl:param name="certain" />
		<xsl:param name="node" />
		<tr>
			<xsl:if test="$certain='false'">
				<xsl:text>* </xsl:text>
			</xsl:if>
			<xsl:value-of select="$node" />
		</tr>
	</xsl:template>

	<xsl:template name="optional-citemarker">
	</xsl:template>

	<xsl:template name="hyperlink">
		<xsl:param name="name" />
		<xsl:value-of select='$name' />
	</xsl:template>

	<xsl:template name="times-symbol">
		<xsl:text>* </xsl:text>
	</xsl:template>

</xsl:stylesheet>
