<?xml version="1.0" encoding="UTF-8"?>

<xsl:stylesheet version="1.0"
		xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

	<xsl:output method="text" />

	<xsl:import href="transformbase.xsl" />

	<xsl:template match="signlist">\documentclass[12pt]{article}

\usepackage[cm]{fullpage}
\usepackage{graphicx}
\usepackage{ifthen}
\usepackage{color}
\usepackage{setspace}
\usepackage{hyperref}

\input{restex}

\sloppy

\title{The 1071 hieroglyphs from Unicode 5.2}
\author{Mark-Jan Nederhof}
\date{\ }

\begin{document}

\maketitle
\begin{abstract}
This is the PDF version of the main tables at
\url{https://mjn.host.cs.st-andrews.ac.uk/egyptian/unicode/} ,
which contains the most up-to-date information.
\end{abstract}

\StartResTex

			<xsl:apply-templates select="sign" />

\EndResTex

\end{document}
	</xsl:template>

	<xsl:template match="sign">
		<xsl:variable name="signid" select="@id" />
		<xsl:variable name="descr"
			select="$description/signlist/sign[@id=$signid]" />
		<xsl:variable name="readings"
			select="$use/signlist/sign[@id=$signid]" />
		<xsl:variable name="others"
			select="$relations/signlist/sign[@id=$signid]" />

\noindent
\hypertarget{<xsl:value-of select="$signid" />}{\textbf{<xsl:value-of select="$signid" />}}
\ResMain{<xsl:value-of select="$signid" />} :
<xsl:if test="$descr/descr/node()">
	<xsl:apply-templates select="$descr/descr/node()" />
	<xsl:text>.</xsl:text>
</xsl:if>
		
		<xsl:for-each select="$readings/*[name()!='p']">
			<xsl:call-template name="newline"/>
			<xsl:call-template name="newline"/>
			<xsl:apply-templates select="." />
		</xsl:for-each>

		<xsl:for-each select="$readings/p">
			<xsl:call-template name="newline"/>
			<xsl:call-template name="newline"/>
			<xsl:apply-templates />
		</xsl:for-each>

		<xsl:if test="$relations/signlist/sign[distinct/@name=$signid] or $others/distinct">
			<xsl:call-template name="newline"/>
			<xsl:call-template name="newline"/>
				<xsl:text>Do not confuse with: </xsl:text>
				<xsl:for-each
					select="$relations/signlist/sign[distinct/@name=$signid]">
					<xsl:call-template name="signreference">
						<xsl:with-param name="name" select="@id" />
					</xsl:call-template>
					<xsl:if test="position()&lt;last() or $others/distinct">
						<xsl:text>, </xsl:text>
					</xsl:if>
				</xsl:for-each>
				<xsl:for-each select="$others/distinct">
					<xsl:call-template name="signreference">
						<xsl:with-param name="name" select="@name" />
					</xsl:call-template>
					<xsl:if test="position()&lt;last()">
						<xsl:text>, </xsl:text>
					</xsl:if>
				</xsl:for-each>
				<xsl:text>. </xsl:text>
		</xsl:if>

		<xsl:call-template name="newline"/>
		<xsl:call-template name="newline"/>
		<xsl:text>\medskip</xsl:text>
	</xsl:template>

<!-- Specific to Latex -->

	<xsl:template name="highlighted-class-name">
		<xsl:param name="class" />
		<xsl:text>\textbf{</xsl:text>
			<xsl:call-template name="class-name">
				<xsl:with-param name="class" select="$class" />
			</xsl:call-template>
		<xsl:text>}</xsl:text>
	</xsl:template>

	<xsl:template name="highlighted-ex">
		<xsl:text>Ex.\ </xsl:text>
	</xsl:template>

	<xsl:template name="highlighted-exx">
		<xsl:text>Exx.\ </xsl:text>
	</xsl:template>

	<xsl:template name="example-environment">
		<xsl:call-template name="example" />
	</xsl:template>

	<xsl:template name="hieroglyphic">
		<xsl:param name="node" />
		<xsl:text>\ResMain{</xsl:text>
		<xsl:value-of select="$node" />
		<xsl:text>} </xsl:text>
	</xsl:template>

	<xsl:template name="sign">
		<xsl:param name="signid" />
		<xsl:text>\ResMain{</xsl:text>
		<xsl:value-of select="$signid" />
		<xsl:text>} </xsl:text>
	</xsl:template>

	<xsl:template name="sign-and-id">
		<xsl:param name="signid" />
		<xsl:call-template name="sign">
			<xsl:with-param name="signid" select="$signid" />
		</xsl:call-template>
		<xsl:text>~</xsl:text>
		<xsl:value-of select="$signid" />
	</xsl:template>

	<xsl:template name="transliteration">
		<xsl:param name="certain" />
		<xsl:param name="node" />
		<xsl:if test="$certain='false'">
			<xsl:text>* </xsl:text>
		</xsl:if>
		<xsl:text>\TranslitMain{</xsl:text>
		<xsl:value-of select="$node" />
		<xsl:text>}</xsl:text>
	</xsl:template>

	<xsl:template name="translation">
		<xsl:param name="certain" />
		<xsl:param name="node" />
		<xsl:text>\textit{</xsl:text>
		<xsl:if test="$certain='false'">
			<xsl:text>* </xsl:text>
		</xsl:if>
		<xsl:value-of select="$node" />
		<xsl:text>}</xsl:text>
	</xsl:template>

	<xsl:template name="optional-citemarker">
	</xsl:template>

	<xsl:template name="hyperlink">
		<xsl:param name="name" />
		<xsl:text>\hyperlink{</xsl:text>
		<xsl:value-of select='$name' />
		<xsl:text>}{</xsl:text>
		<xsl:value-of select='$name' />
		<xsl:text>}</xsl:text>
	</xsl:template>

	<xsl:template name="times-symbol">
		<xsl:text> $\times$ </xsl:text>
	</xsl:template>

</xsl:stylesheet>
