<?xml version="1.0" encoding="UTF-8"?>

<xsl:stylesheet version="1.0"
       xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

    <xsl:variable name="bibl" select="document('bibliography.xml')" />
    <xsl:variable name="description" select="document('signdescriptioneng.xml')" />
    <xsl:variable name="dimensions" select="document('signdimensions.xml')" />
    <xsl:variable name="formal" select="document('signformal.xml')" />
    <xsl:variable name="egpz" select="document('signegpz.xml')" />
    <xsl:variable name="encoding" select="document('signencoding.xml')" />
    <xsl:variable name="hieratic" select="document('signhieratic.xml')" />
    <xsl:variable name="mnemonics" select="document('signmnemonics.xml')" />
    <xsl:variable name="relations" select="document('signrelations.xml')" />
    <xsl:variable name="sources" select="document('signsources.xml')" />
    <xsl:variable name="unicode" select="document('signunicode.xml')" />
    <xsl:variable name="use" select="document('signuse.xml')" />
    <xsl:variable name="tsl" select="document('signtsl.xml')" />

    <xsl:template name="class-name">
        <xsl:param name="class" />
        <xsl:choose>
            <xsl:when test="$class='log'">
                <xsl:text>Log.</xsl:text>
            </xsl:when>
            <xsl:when test="$class='det'">
                <xsl:text>Det.</xsl:text>
            </xsl:when>
            <xsl:when test="$class='logdet'">
                <xsl:text>Log. or det.</xsl:text>
            </xsl:when>
            <xsl:when test="$class='phon'">
                <xsl:text>Phon.</xsl:text>
            </xsl:when>
            <xsl:when test="$class='phondet'">
                <xsl:text>Phon. det.</xsl:text>
            </xsl:when>
            <xsl:when test="$class='phonphondet'">
                <xsl:text>Phon. or phon. det.</xsl:text>
            </xsl:when>
            <xsl:when test="$class='typ'">
                <xsl:text>Typ.</xsl:text>
            </xsl:when>
        </xsl:choose>
    </xsl:template>

    <xsl:template match="log">
        <xsl:call-template name="specification">
            <xsl:with-param name="class" select="name()" />
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="det">
        <xsl:call-template name="specification">
            <xsl:with-param name="class" select="name()" />
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="logdet">
        <xsl:call-template name="specification">
            <xsl:with-param name="class" select="name()" />
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="phon">
        <xsl:if test="@type='group'">
            <xsl:text>(group-writing) </xsl:text>
        </xsl:if>
        <xsl:call-template name="specification">
            <xsl:with-param name="class" select="name()" />
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="phondet">
        <xsl:call-template name="specification">
            <xsl:with-param name="class" select="name()" />
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="phonphondet">
        <xsl:call-template name="specification">
            <xsl:with-param name="class" select="name()" />
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="typ">
        <xsl:call-template name="specification">
            <xsl:with-param name="class" select="name()" />
        </xsl:call-template>
    </xsl:template>

   <xsl:template match="useas">
        <xsl:for-each select="group">
            <xsl:call-template name="group" />
            <xsl:if test="position()&lt;last()">
                <xsl:text>, </xsl:text>
            </xsl:if>
        </xsl:for-each>
        <xsl:variable name="name" select="@name" />
        <xsl:text> Usage as </xsl:text>
        <xsl:if test="@number">
            <xsl:value-of select="@number" />
	    <xsl:call-template name="times-symbol" />
        </xsl:if>
        <xsl:call-template name="signreference">
            <xsl:with-param name="name" select="$name" />
        </xsl:call-template>
        <xsl:choose>
            <xsl:when test="@use">
                <xsl:text> [</xsl:text>
                <xsl:call-template name="class-name">
                    <xsl:with-param name="class" select="@use" />
                </xsl:call-template>
                <xsl:text>]</xsl:text>
            </xsl:when>
            <xsl:when test="@useref">
                <xsl:call-template name="use-identifier">
                    <xsl:with-param name="name" select="$name" />
                    <xsl:with-param name="useref" select="@useref" />
                </xsl:call-template>
            </xsl:when>
        </xsl:choose>
        <xsl:text>. </xsl:text>
        <xsl:call-template name="examples" />
    </xsl:template>

    <xsl:template name="use-identifier">
        <xsl:param name="name" />
        <xsl:param name="useref" />
        <xsl:variable name="signuse"
		select="$use/signlist/sign[@id=$name]/*[@useid=$useref]" />
        <xsl:text> [</xsl:text>
        <xsl:call-template name="class-name">
            <xsl:with-param name="class" select="name($signuse)" />
        </xsl:call-template>
        <xsl:choose>
            <xsl:when test="$signuse/describe">
                <xsl:text> </xsl:text>
                <xsl:value-of select="$signuse/describe" />
            </xsl:when>
            <xsl:when test="$signuse/al|$signuse/tr">
                <xsl:text> </xsl:text>
                <xsl:for-each select="$signuse/al|$signuse/tr">
                    <xsl:apply-templates select="."/>
                    <xsl:if test="position()&lt;last()">
                        <xsl:text>, </xsl:text>
                    </xsl:if>
                </xsl:for-each>
            </xsl:when>
        </xsl:choose>
        <xsl:text>]</xsl:text>
    </xsl:template>

    <xsl:template name="specification">
        <xsl:param name="class" />
        <xsl:for-each select="group">
            <xsl:call-template name="group" />
            <xsl:if test="position()&lt;last()">
                <xsl:text>, </xsl:text>
            </xsl:if>
        </xsl:for-each>
        <xsl:call-template name="highlighted-class-name">
            <xsl:with-param name="class" select="$class" />
        </xsl:call-template>
        <xsl:text> </xsl:text>
        <xsl:call-template name="reading-parts" />
        <xsl:call-template name="examples" />
    </xsl:template>

    <xsl:template name="reading-parts">
        <xsl:for-each select="describe|hi|al|tr">
            <xsl:apply-templates select="."/>
            <xsl:if test="position()&lt;last()">
                <xsl:text>, </xsl:text>
            </xsl:if>
        </xsl:for-each>
        <xsl:if test="count(describe|hi|al|tr)>0">
            <xsl:text>. </xsl:text>
        </xsl:if>
    </xsl:template>

    <xsl:template name="examples">
        <xsl:if test="count(example)=1">
            <xsl:call-template name="highlighted-ex" />
        </xsl:if>
        <xsl:if test="count(example)>1">
            <xsl:call-template name="highlighted-exx" />
        </xsl:if>
        <xsl:for-each select="example">
            <xsl:call-template name="example-environment" />
            <xsl:if test="position()&lt;last()">
                <xsl:text>; </xsl:text>
            </xsl:if>
        </xsl:for-each>
        <xsl:if test="count(example)>0">
            <xsl:text>. </xsl:text>
        </xsl:if>
    </xsl:template>

    <xsl:template name="example">
        <xsl:for-each select="hi|al|tr">
            <xsl:apply-templates select="."/>
            <xsl:if test="position()&lt;last()">
                <xsl:text>, </xsl:text>
            </xsl:if>
        </xsl:for-each>
    </xsl:template>

    <xsl:template match="signref">
        <xsl:call-template name="signreference">
            <xsl:with-param name="name" select="@name" />
        </xsl:call-template>
    </xsl:template>

    <xsl:template name="signreference">
        <xsl:param name="name" />
        <xsl:call-template name="sign">
           <xsl:with-param name="signid" select="$name" />
        </xsl:call-template>
        <xsl:call-template name="hyperlink">
           <xsl:with-param name="name" select="$name" />
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="describe">
        <xsl:apply-templates select="node()"/>
    </xsl:template>

    <xsl:template name="group">
        <xsl:call-template name="hieroglyphic">
           <xsl:with-param name="node" select="." />
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="hi">
        <xsl:call-template name="hieroglyphic">
           <xsl:with-param name="node" select="." />
        </xsl:call-template>
        <xsl:if test="@cite[. != '']">
            <xsl:call-template name="optional-citemarker" />
        </xsl:if>
    </xsl:template>

    <xsl:template match="al">
        <xsl:call-template name="transliteration">
           <xsl:with-param name="certain" select="@certain" />
           <xsl:with-param name="node" select="." />
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="tr">
        <xsl:call-template name="translation">
           <xsl:with-param name="certain" select="@certain" />
           <xsl:with-param name="node" select="." />
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="node()|@*">
        <xsl:copy>
            <xsl:apply-templates select="node()|@*" />
        </xsl:copy>
    </xsl:template>

<!-- Auxiliary -->

    <xsl:template name="newline">
        <xsl:text>
</xsl:text>
    </xsl:template>

</xsl:stylesheet>
