<?xml version="1.0" encoding="UTF-8"?>

<!DOCTYPE xsl:stylesheet [
<!ENTITY nbsp "&#160;">
]>

<xsl:stylesheet version="1.0"
		xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
		xmlns:datetime="http://exslt.org/dates-and-times">

	<xsl:import href="transform2html.xsl" />

	<xsl:template match="signlist">
		<html>
		<head>
			<title>Sign list: relations</title>
			<xsl:call-template name="style" />
		</head>
		<body>
			<xsl:call-template name="font-hack" />
			<a href="index.html"><img src="uparr.jpg" alt="" />
				<b>Sign list</b>
			</a>

			<h1>The 1071 hieroglyphs from Unicode 5.2</h1>
			<h2>Relations between signs</h2>

			<xsl:for-each select="$relations/signlist/p">
				<p> <xsl:apply-templates /> </p>
			</xsl:for-each>

			<table rules="all">
				<tr>
					<th>Sign</th>
					<th>Contains</th>
					<th>Graphical</th>
					<th>Confused</th>
					<th>Distinct</th>
					<!-- <th>Comments</th> -->
				</tr>
				<xsl:apply-templates select="sign" />
			</table>

			<p>
			<i>Last update: <xsl:value-of select="datetime:dateTime()" /></i>
			</p>
		</body>
		</html>
	</xsl:template>

	<xsl:template match="sign">
		<xsl:variable name="signid" select="@id" />
		<xsl:variable name="others"
			select="$relations/signlist/sign[@id=$signid]" />
		<tr>
			<xsl:attribute name="id">
				<xsl:value-of select="$signid" />
			</xsl:attribute>
			<th>
				<xsl:call-template name="sign-and-id">
					<xsl:with-param name="signid" select="$signid" />
				</xsl:call-template>
			</th>
			<td>
				<xsl:for-each select="$others/contains">
					<xsl:call-template name="signreference">
						<xsl:with-param name="name" select="@name" />
					</xsl:call-template>
					<xsl:if test="position()&lt;last()">
						<xsl:text>, </xsl:text>
					</xsl:if>
				</xsl:for-each>
			</td>
			<td>
				<xsl:for-each select="$others/variant">
					<xsl:call-template name="signreference">
						<xsl:with-param name="name" select="@name" />
					</xsl:call-template>
					<xsl:text> (</xsl:text>
					<span class="warning">variant</span>
					<xsl:text>)</xsl:text>
				</xsl:for-each>
				<xsl:for-each select="$others/similar">
					<xsl:call-template name="signreference">
						<xsl:with-param name="name" select="@name" />
					</xsl:call-template>
					<xsl:text> (</xsl:text>
					<span class="okay">similar</span>
					<xsl:text>)</xsl:text>
				</xsl:for-each>
			</td>
			<td>
				<xsl:for-each
					select="$relations/signlist/sign[confused/@name=$signid]">
					<xsl:call-template name="signreference">
						<xsl:with-param name="name" select="@id" />
					</xsl:call-template>
					<xsl:for-each select="confused[@name=$signid]">
						<xsl:if test="@texttype">
							<xsl:text> (</xsl:text>
							<xsl:value-of select="@texttype" />
							<xsl:text>)</xsl:text>
						</xsl:if>
					</xsl:for-each>
					<xsl:if test="position()&lt;last() or $others/confused">
						<xsl:text><br/></xsl:text>
					</xsl:if>
				</xsl:for-each>
				<xsl:for-each select="$others/confused">
					<xsl:call-template name="signreference">
						<xsl:with-param name="name" select="@name" />
					</xsl:call-template>
					<xsl:if test="@texttype">
						<xsl:text> (</xsl:text>
						<xsl:value-of select="@texttype" />
						<xsl:text>)</xsl:text>
					</xsl:if>
					<xsl:if test="position()&lt;last()">
						<xsl:text><br/></xsl:text>
					</xsl:if>
				</xsl:for-each>
			</td>
			<td>
				<xsl:for-each
					select="$relations/signlist/sign[distinct/@name=$signid]">
					<xsl:call-template name="signreference">
						<xsl:with-param name="name" select="@id" />
					</xsl:call-template>
					<xsl:if test="position()&lt;last() or $others/distinct">
						<xsl:text>, </xsl:text>
					</xsl:if>
				</xsl:for-each>
				<xsl:for-each select="$others/distinct">
					<xsl:call-template name="signreference">
						<xsl:with-param name="name" select="@name" />
					</xsl:call-template>
					<xsl:if test="position()&lt;last()">
						<xsl:text>, </xsl:text>
					</xsl:if>
				</xsl:for-each>
			</td>
		</tr>
	</xsl:template>

</xsl:stylesheet>
