<?xml version="1.0" encoding="UTF-8"?>

<!DOCTYPE xsl:stylesheet [
<!ENTITY nbsp "&#160;">
]>

<xsl:stylesheet version="1.0"
		xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
		xmlns:datetime="http://exslt.org/dates-and-times">

	<xsl:import href="transform2html.xsl" />

	<xsl:template match="signlist">
		<html>
		<head>
			<title>Sign list: encoding</title>
			<xsl:call-template name="style" />
		</head>
		<body>
			<xsl:call-template name="font-hack" />
			<a href="index.html"><img src="uparr.jpg" alt="" /> 
				<b>Sign list</b>
			</a>

			<h1>The 1071 hieroglyphs from Unicode 5.2</h1>
			<h2>Encoding</h2>

			<xsl:for-each select="$unicode/signlist/p">
				<p> <xsl:apply-templates /> </p>
			</xsl:for-each>
			<xsl:for-each select="$egpz/signlist/p">
				<p> <xsl:apply-templates /> </p>
			</xsl:for-each>
			<xsl:for-each select="$mnemonics/signlist/p">
				<p> <xsl:apply-templates /> </p>
			</xsl:for-each>
			<xsl:for-each select="$encoding/signlist/p">
				<p> <xsl:apply-templates /> </p>
			</xsl:for-each>

			<table rules="all">
				<tr>
					<th>Sign</th>
					<th>Unicode</th>
					<th>EGPZ</th>
					<th>Mnemonics</th>
					<th>Status</th>
					<th>Alternative</th>
					<th>Comments</th>
				</tr>
				<xsl:apply-templates select="sign" />
			</table>

			<p>
			<i>Last update: <xsl:value-of select="datetime:dateTime()" /></i>
			</p>
		</body>
		</html>
	</xsl:template>

	<xsl:template match="sign">
		<xsl:variable name="signid" select="@id" />
		<xsl:variable name="code"
			select="$unicode/signlist/sign[@id=$signid]" />
		<xsl:variable name="altcode"
			select="$egpz/signlist/sign[@id=$signid]" />
		<xsl:variable name="res"
			select="$encoding/signlist/sign[@id=$signid]" />
		<tr>
			<xsl:attribute name="id">
				<xsl:value-of select="$signid" />
			</xsl:attribute>
			<th>
				<xsl:call-template name="sign-and-id">
					<xsl:with-param name="signid" select="$signid" />
				</xsl:call-template>
			</th>
			<td><xsl:value-of select="$code/@code" /></td>
			<td><xsl:value-of select="$altcode/@code" /></td>
			<td>
				<xsl:for-each select="$mnemonics/signlist/sign[@id=$signid]">
					<xsl:value-of select="@code" />
					<xsl:if test="position()&lt;last()">
						<xsl:text>, </xsl:text>
					</xsl:if>
				</xsl:for-each>
			</td>
			<td>
				<xsl:if test="$res/node()/@status='deprecated'">
					<span class="warning">deprecated</span>
				</xsl:if>
				<xsl:if test="$res/node()/@status='confirmed'">
					<span class="okay">confirmed</span>
				</xsl:if>
			</td>
			<td>
				<xsl:if test="not(normalize-space($res/combine)='')">
					<xsl:value-of select="$res/combine" />
				</xsl:if>
				<xsl:if test="not(normalize-space($res/insert)='')">
					<xsl:value-of select="$res/insert" />
				</xsl:if>
				<xsl:if test="not(normalize-space($res/mirror)='')">
					<xsl:value-of select="$res/mirror" />
				</xsl:if>
				<xsl:if test="not(normalize-space($res/omit)='')">
					<xsl:value-of select="$res/omit" />
				</xsl:if>
				<xsl:if test="not(normalize-space($res/rotate)='')">
					<xsl:value-of select="$res/rotate" />
				</xsl:if>
				<xsl:if test="not(normalize-space($res/scale)='')">
					<xsl:value-of select="$res/scale" />
				</xsl:if>
				<xsl:if test="not(normalize-space($res/stack)='')">
					<xsl:value-of select="$res/stack" />
				</xsl:if>
			</td>
			<td>
				<xsl:for-each select="$res/p">
					<p> <xsl:apply-templates /> </p>
				</xsl:for-each>
			</td>
		</tr>
	</xsl:template>

</xsl:stylesheet>
