#!/bin/bash

# Take transliteration in makelazytmp, divide it into words,
# turn words into images, and include the words in a Latex file.

# Temporary file from which transliteration is read.
tmp="makelazytmp"

# Where are auxiliary graphics stored.
graphics_dir=restex-graphics

# The arguments.
texfile=$1
fontsize=$2
raising=$3
style=$4

# Make image for word.
make_word_file() {
    raw=$1;
    name="restex-t$fontsize-"
    for ((i=0; i < ${#1}; i++))
    do
	c=${raw:i:1};
	if [[ ("a" = "$c" || "a" < "$c") &&
		("z" = "$c" || "$c" < "z") ||
	      ("A" = "$c" || "A" < "$c") &&
                ("Z" = "$c" || "$c" < "Z") ]];
	then
	    name="$name$c";
	else
	    code=`printf "%d" "'$c"`;
	    name="$name-$code-";
	fi
    done 
    if [[ !(-f $graphics_dir/$name.eps || -f $graphics_dir/$name.pdf) ]];
    then
	java -cp philologeg:philologeg/lib/itextpdf-5.4.3.jar nederhof/images/TransliterationImage \
		$1 $graphics_dir/$name.eps $fontsize $style
    fi
    echo $name
}

# At beginning of input.
tex=""
word=""

while read -n1 char
do
    if [[ "$char" = "\$" ]];
    then
        break;
    elif [[ "$char" != "" ]];
    then
	word="$word$char";
    else
	if [[ "$word" != "" ]];
	then
	    file=`make_word_file $word`;
	    include="\raisebox{$raising}{\mbox{\includegraphics{$graphics_dir/$file.pdf}}}";
	    tex="${tex}$include";
	    word="";
	fi
	tex="$tex ";
    fi
done < $tmp

if [[ "$word" != "" ]];
then
    file=`make_word_file $word`;
    include="\raisebox{$raising}{\mbox{\includegraphics{$graphics_dir/$file.pdf}}}";
    tex="${tex}$include";
    word="";
fi

echo "$tex" > $texfile

